@@ -13,6 +13,8 @@ modules = [
     "nautilusburn",
     "mediaprofiles",
     "metacity",
+    "rsvg",
+    "gnomekeyring",
     ]
 
 import ltihooks
